==> haskell-hasql-1.5.0.4-113-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql
version:              1.5.0.4
visibility:           public
id:                   hasql-1.5.0.4-3X2mZlxdWL044URuQ7OkF4
key:                  hasql-1.5.0.4-3X2mZlxdWL044URuQ7OkF4
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql
synopsis:             An efficient PostgreSQL driver with a flexible mapping API
description:
    Root of the \"hasql\" ecosystem.
    For details and tutorials see
    <https://github.com/nikita-volkov/hasql the readme>.

    The API comes free from all kinds of exceptions. All error-reporting is explicit and is presented using the '\''Either'\'' type.

category:             Hasql, Database, PostgreSQL
abi:                  5c95aebf0bd40625dfaaddec0b43b660
exposed:              True
exposed-modules:
    Hasql.Connection Hasql.Decoders Hasql.Encoders Hasql.Session
    Hasql.Statement

hidden-modules:
    Hasql.Private.Prelude Hasql.Private.Errors Hasql.Private.PTI
    Hasql.Private.IO Hasql.Private.Session Hasql.Private.Connection
    Hasql.Private.PreparedStatementRegistry Hasql.Private.Settings
    Hasql.Private.Commands Hasql.Private.Decoders
    Hasql.Private.Decoders.Array Hasql.Private.Decoders.Composite
    Hasql.Private.Decoders.Value Hasql.Private.Decoders.Row
    Hasql.Private.Decoders.Result Hasql.Private.Decoders.Results
    Hasql.Private.Encoders Hasql.Private.Encoders.Array
    Hasql.Private.Encoders.Value Hasql.Private.Encoders.Params

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hasql-1.5.0.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hasql-1.5.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql
hs-libraries:         HShasql-1.5.0.4-3X2mZlxdWL044URuQ7OkF4
depends:
    attoparsec-0.14.4-l6gpYVAuXa4krkAJlMwbn base-4.16.4.0
    bytestring-0.11.4.0
    bytestring-strict-builder-0.4.5.7-GtktvIDgul687GXAa91azy
    contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq
    dlist-1.0-HCxoMn9TirQDgPCFxho7O
    hashable-1.4.3.0-7566tBsT9J8EFScR3Tb2Bc
    hashtables-1.3.1-1HRPfBbX63X7eo6Liqco8I mtl-2.2.2
    postgresql-binary-0.12.5-DvGO0TtaGuUJrIEcWcZkZE
    postgresql-libpq-0.9.4.3-KEIdZq7PBXuLHl7WTAWu9q
    profunctors-5.6.2-H5X8seMFIwDFEHBxAhvjxL text-1.2.5.0
    text-builder-0.6.7-BwDH1X984Rs70mCeFGuiM6 transformers-0.5.6.2
    vector-0.13.1.0-HyaXkpW7aOFHhHqdwTfvZq

haddock-interfaces:   /usr/share/doc/haskell-hasql/html/hasql.haddock
haddock-html:         /usr/share/doc/haskell-hasql/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-1.5.0.4-126-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql
version:              1.5.0.4
visibility:           public
id:                   hasql-1.5.0.4-6GDwBu1ouGLL97aqfLNtDJ
key:                  hasql-1.5.0.4-6GDwBu1ouGLL97aqfLNtDJ
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql
synopsis:             An efficient PostgreSQL driver with a flexible mapping API
description:
    Root of the \"hasql\" ecosystem.
    For details and tutorials see
    <https://github.com/nikita-volkov/hasql the readme>.

    The API comes free from all kinds of exceptions. All error-reporting is explicit and is presented using the '\''Either'\'' type.

category:             Hasql, Database, PostgreSQL
abi:                  d2c2793eab64017dc2b8bf2b235c2d4d
exposed:              True
exposed-modules:
    Hasql.Connection Hasql.Decoders Hasql.Encoders Hasql.Session
    Hasql.Statement

hidden-modules:
    Hasql.Private.Prelude Hasql.Private.Errors Hasql.Private.PTI
    Hasql.Private.IO Hasql.Private.Session Hasql.Private.Connection
    Hasql.Private.PreparedStatementRegistry Hasql.Private.Settings
    Hasql.Private.Commands Hasql.Private.Decoders
    Hasql.Private.Decoders.Array Hasql.Private.Decoders.Composite
    Hasql.Private.Decoders.Value Hasql.Private.Decoders.Row
    Hasql.Private.Decoders.Result Hasql.Private.Decoders.Results
    Hasql.Private.Encoders Hasql.Private.Encoders.Array
    Hasql.Private.Encoders.Value Hasql.Private.Encoders.Params

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hasql-1.5.0.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hasql-1.5.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql
hs-libraries:         HShasql-1.5.0.4-6GDwBu1ouGLL97aqfLNtDJ
depends:
    attoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq base-4.16.4.0
    bytestring-0.11.4.0
    bytestring-strict-builder-0.4.5.7-91hWpCQiiJZ2nPkepLCONN
    contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq
    dlist-1.0-LNr75TD4CZoKEEzkBmhWjA
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    hashtables-1.3.1-19pwafFiCaCEjS0N0RfZKT mtl-2.2.2
    postgresql-binary-0.12.5-I5I5yYOcQWbBvePGnSWMAC
    postgresql-libpq-0.9.4.3-KEIdZq7PBXuLHl7WTAWu9q
    profunctors-5.6.2-FWe4PQU8eE3GeDqm3R4ckm text-1.2.5.0
    text-builder-0.6.7-bWO1uP3xY5GNnPsBNUejA transformers-0.5.6.2
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:   /usr/share/doc/haskell-hasql/html/hasql.haddock
haddock-html:         /usr/share/doc/haskell-hasql/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
